-- This file contains adapted parts of FS22_SlipDestroysFields by frvetz and is licensed under
-- GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007.

source(g_currentModDirectory .. "TypeControlOptions.lua")

SettingsChangeEvent = {}
local SettingsChangeEvent_mt = Class(SettingsChangeEvent, Event)
InitEventClass(SettingsChangeEvent, "SettingsChangeEvent")

function SettingsChangeEvent.emptyNew()
	local event = Event.new(SettingsChangeEvent_mt)

	event.typeControlOptions = getTypeControlOptions()

	return event
end

function SettingsChangeEvent.new(baseYear, baseYearState, minimumOneAvailable, typeControlOptions)
    local event = SettingsChangeEvent.emptyNew()

	event.baseYear = baseYear
	event.baseYearState = baseYearState
	event.minimumOneAvailable = minimumOneAvailable
	event.typeControlOptions = typeControlOptions

	return event
end

function SettingsChangeEvent:readStream(streamId, connection)
    self.baseYear = streamReadInt32(streamId)
    self.baseYearState = streamReadInt32(streamId)
    self.minimumOneAvailable = streamReadBool(streamId)

	for category, value in pairsByKeys(self.typeControlOptions) do
		self.typeControlOptions[category].stateIsEnabled = streamReadBool(streamId)
	end

	self:run(connection)
end

function SettingsChangeEvent:writeStream(streamId, connection)
	streamWriteInt32(streamId, self.baseYear)
	streamWriteInt32(streamId, self.baseYearState)
	streamWriteBool(streamId, self.minimumOneAvailable)

	for category, value in pairsByKeys(self.typeControlOptions) do
		streamWriteBool(streamId, self.typeControlOptions[category].stateIsEnabled)
	end
end

function SettingsChangeEvent:run(connection)
	ThroughTheYears.SettingsChanged(self.baseYear, self.baseYearState,
									self.minimumOneAvailable, self.typeControlOptions)

	if not connection:getIsServer() then
		g_server:broadcastEvent(SettingsChangeEvent.new(self.baseYear, self.baseYearState,
													    self.minimumOneAvailable,
														self.typeControlOptions))
	end
end
